==> digikam-4.7.0.tar.bz2: digikam-4.7.0/extra/kipi-plugins/imgurexport/kipiplugin_imgurexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Imgur Export
Name=Imgur Export
Name[bs]=Imgur Izvoz
Name[ca]=Exportador a Imgur
Name[ca@valencia]=Exportador a Imgur
Name[cs]=Export Imgur
Name[da]=Eksport til Imgur
Name[de]=Imgur-Export
Name[el]=Εξαγωγή Imgur
Name[en_GB]=Imgur Export
Name[es]=Exportar a Imgur
Name[et]=Imguri eksport
Name[fi]=Imgur-vienti
Name[fr]=Exportation « Imgur »
Name[ga]=Easpórtáil Imgur
Name[gl]=Exportación a Imgur
Name[hu]=Imgur exportálás
Name[is]=Imgur útflutningur
Name[it]=Esportazione a Imgur
Name[km]=នាំចេញ Imgur
Name[nb]=Imgur-eksport
Name[nl]=Imgur-export
Name[pl]=Eksport Imgur
Name[pt]=Exportação para o Imgur
Name[pt_BR]=Exportar para o Imgur
Name[ru]=Экспорт в Imgur
Name[sk]=Imgur Export
Name[sl]=Izvoz Imgur
Name[sv]=Export till Imgur
Name[tr]=Imgur Aktarımı
Name[uk]=Експорт до Imgur
Name[x-test]=xxImgur Exportxx
Name[zh_CN]=Imgur导出
Name[zh_TW]=Imgur 匯出
Comment=A tool to export images to the imgur.com image hosting service
Comment[bs]=Alat za izvoz slika u imgur.com image hosting servisu
Comment[ca]=Una eina per exportar imatges al servei d'allotjament d'imatges imgur.com
Comment[ca@valencia]=Una eina per exportar imatges al servei d'allotjament d'imatges imgur.com
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby imgur.com
Comment[da]=Et værktøj til at eksportere billeder til billedupload-tjenesten imgur.com
Comment[de]=Ein Werkzeug, um Bilder zum imgur.com-Service zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων στην υπηρεσία φιλοξενίας εικόνων imgur.com
Comment[en_GB]=A tool to export images to the imgur.com image hosting service
Comment[es]=Una herramienta para exportar imágenes al servicio imgur.com
Comment[et]=Tööriist piltide eksportimiseks imgur.com-i veebiteenusesse
Comment[fi]=Kuvien vienti imgur.com-kuvientallennuspalveluun
Comment[fr]=Outil pour l'exportation d'images vers le service en ligne d'hébergement d'images « imgur.com »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís óstála imgur.com
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web imgur.com remoto
Comment[hu]=Egy eszköz képek exportálásához az imgur.com webhelyszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á imgur.com vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio di immagini imgur.com
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចេញ​រូបភាព​ទៅ​ជា​រូបភាព imgur.com ដោយ​បង្ហោះ​សេវាកម្ម
Comment[nb]=Et verktøy for å eksportere bilder til bildevertstjenesten imgur.com
Comment[nl]=Een hulpmiddel om afbeeldingen naar de imgur.com hostingservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej imgur.com
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do imgur.com
Comment[pt_BR]=Ferramenta para exportar imagens para o imgur.com
Comment[ru]=Инструмент для экспорта изображений в веб-службу imgur.com
Comment[sk]=Nástroj na export obrázkov na hostovaciu službu imgur.com
Comment[sl]=Orodje za izvoz slik v storitev gostovanja slik imgur.com
Comment[sv]=Ett verktyg för att exportera bilder till en imgur.com bildlagringstjänst
Comment[tr]=Resimleri imgur.com resim barındırma hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до сховища зображень imgur.com
Comment[x-test]=xxA tool to export images to the imgur.com image hosting servicexx
Comment[zh_TW]=匯出影像到 imgur.com 影像主機服務的工具
Type=Service
Icon=kipi-imgur
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_imgurexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Marius Orcsik, marius at habarnam dot ro

==> digikam-4.14.0.tar.bz2: digikam-4.14.0/extra/kipi-plugins/imgurexport/kipiplugin_imgurexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Imgur Export
Name=Imgur Export
Name[bs]=Imgur Izvoz
Name[ca]=Exportador a Imgur
Name[ca@valencia]=Exportador a Imgur
Name[cs]=Export Imgur
Name[da]=Eksport til Imgur
Name[de]=Imgur-Export
Name[el]=Εξαγωγή Imgur
Name[en_GB]=Imgur Export
Name[es]=Exportar a Imgur
Name[et]=Imguri eksport
Name[fi]=Imgur-vienti
Name[fr]=Export « Imgur »
Name[ga]=Easpórtáil Imgur
Name[gl]=Exportación a Imgur
Name[hu]=Imgur exportálás
Name[is]=Imgur útflutningur
Name[it]=Esportazione a Imgur
Name[km]=នាំចេញ Imgur
Name[nb]=Imgur-eksport
Name[nl]=Imgur-export
Name[pl]=Eksport Imgur
Name[pt]=Exportação para o Imgur
Name[pt_BR]=Exportar para o Imgur
Name[ru]=Экспорт в Imgur
Name[sk]=Imgur Export
Name[sl]=Izvoz Imgur
Name[sv]=Export till Imgur
Name[tr]=Imgur Aktarımı
Name[uk]=Експорт до Imgur
Name[x-test]=xxImgur Exportxx
Name[zh_CN]=Imgur导出
Name[zh_TW]=Imgur 匯出
Comment=A tool to export images to the imgur.com image hosting service
Comment[bs]=Alat za izvoz slika u imgur.com image hosting servisu
Comment[ca]=Una eina per exportar imatges al servei d'allotjament d'imatges imgur.com
Comment[ca@valencia]=Una eina per exportar imatges al servei d'allotjament d'imatges imgur.com
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby imgur.com
Comment[da]=Et værktøj til at eksportere billeder til billedupload-tjenesten imgur.com
Comment[de]=Ein Werkzeug, um Bilder zum imgur.com-Service zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων στην υπηρεσία φιλοξενίας εικόνων imgur.com
Comment[en_GB]=A tool to export images to the imgur.com image hosting service
Comment[es]=Una herramienta para exportar imágenes al servicio imgur.com
Comment[et]=Tööriist piltide eksportimiseks imgur.com-i veebiteenusesse
Comment[fi]=Kuvien vienti imgur.com-kuvientallennuspalveluun
Comment[fr]=Outil pour l'export d'images vers le service en ligne d'hébergement d'images « imgur.com »
Comment[ga]=Uirlis a easpórtálann íomhánna go seirbhís óstála imgur.com
Comment[gl]=Unha ferramenta para exportar imaxes a un servizo web imgur.com remoto
Comment[hu]=Egy eszköz képek exportálásához az imgur.com webhelyszolgáltatásba
Comment[is]=Verkfæri til að senda myndir á imgur.com vefþjónustu
Comment[it]=Uno strumento per esportare immagini al servizio di immagini imgur.com
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចេញ​រូបភាព​ទៅ​ជា​រូបភាព imgur.com ដោយ​បង្ហោះ​សេវាកម្ម
Comment[nb]=Et verktøy for å eksportere bilder til bildevertstjenesten imgur.com
Comment[nl]=Een hulpmiddel om afbeeldingen naar de imgur.com hostingservice te exporteren
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej usługi sieciowej imgur.com
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do imgur.com
Comment[pt_BR]=Ferramenta para exportar imagens para o imgur.com
Comment[ru]=Инструмент для экспорта изображений в веб-службу imgur.com
Comment[sk]=Nástroj na export obrázkov na hostovaciu službu imgur.com
Comment[sl]=Orodje za izvoz slik v storitev gostovanja slik imgur.com
Comment[sv]=Ett verktyg för att exportera bilder till en imgur.com bildlagringstjänst
Comment[tr]=Resimleri imgur.com resim barındırma hizmetine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до сховища зображень imgur.com
Comment[x-test]=xxA tool to export images to the imgur.com image hosting servicexx
Comment[zh_TW]=匯出影像到 imgur.com 影像主機服務的工具
Type=Service
Icon=kipi-imgur
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_imgurexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Marius Orcsik, marius at habarnam dot ro
